@@ -34,6 +34,7 @@ from .datatypes import (
     AuxItem,
     ConfType,
     CookedMiscInfo,
+    Membership,
     MembershipType,
     PersonalFlags,
     TextStat,
@@ -335,11 +336,11 @@ class AioClient:
     async def request(self, request):
         async with self._send_lock:
             ref_no = await self._conn.send_request(request)
-            log.debug("AioClient: Sent request (ref_no=%s): %s", ref_no, request)
+            #log.debug("AioClient: Sent request (ref_no=%s): %s", ref_no, request)
             assert ref_no not in self._outstanding_requests_events
             self._outstanding_requests_events[ref_no] = asyncio.Event()
 
-        log.debug("AioClient: Waiting for reply to ref_no=%s", ref_no)
+        #log.debug("AioClient: Waiting for reply to ref_no=%s", ref_no)
         await self._outstanding_requests_events[ref_no].wait()
         del self._outstanding_requests_events[ref_no]
         return self._handle_reply(ref_no)
@@ -347,7 +348,7 @@ class AioClient:
     def _handle_reply(self, ref_no):
         assert ref_no in self._reply_queue
         (ok_reply, error_reply) = self._reply_queue.pop(ref_no)
-        log.debug("AioClient: Handling reply (ref_no=%s): %s", ref_no, (ok_reply, error_reply))
+        #log.debug("AioClient: Handling reply (ref_no=%s): %s", ref_no, (ok_reply, error_reply))
         if error_reply is not None:
             # error reply
             raise error_reply
@@ -360,7 +361,7 @@ class AioClient:
         try:
             while self.is_connected():
                 response = await self._conn.read_response()
-                log.debug("AioClient: Received response: %s", response)
+                #log.debug("AioClient: Received response: %s", response)
                 await self._receive_response(response)
         except Exception as e:
             log.error(f"AioClient: Response receiver task exception: {e}")
@@ -1106,12 +1107,19 @@ class AioKomSession(object):
     async def delete_membership(self, pers_no, conf_no):
         await self._client.request(requests.ReqSubMember(conf_no, pers_no))
 
+    async def _create_kom_membership(self, pers_no, membership: Membership) -> KomMembership:
+        if membership.added_by == 0:
+            # If the membership was created before protocol 10.
+            added_by = None
+        else:
+            added_by = await self._get_person_name(membership.added_by)
+        conference = await self._get_uconference(membership.conference)
+        return KomMembership(pers_no, added_by=added_by, conference=conference, membership=membership)
+
     @async_check_connection
     async def get_membership(self, pers_no, conf_no) -> KomMembership:
         membership = await self._client.get_membership(pers_no, conf_no, want_read_ranges=False)
-        added_by = await self._get_person_name(membership.added_by)
-        conference = await self._get_uconference(conf_no)
-        return KomMembership(pers_no, added_by=added_by, conference=conference, membership=membership)
+        return await self._create_kom_membership(pers_no, membership)
 
     @async_check_connection
     async def get_membership_unread(self, pers_no, conf_no) -> KomMembershipUnread:
@@ -1148,11 +1156,7 @@ class AioKomSession(object):
             for membership in ms_list:
                 if (not passive) and membership.type.passive:
                     continue
-                memberships.append(KomMembership(
-                    pers_no,
-                    added_by=await self._get_person_name(membership.added_by),
-                    conference=await self._get_uconference(membership.conference),
-                    membership=membership))
+                memberships.append(await self._create_kom_membership(pers_no, membership))
 
         return memberships, has_more
 
